/* This file is still needed because the defines below are
   AC_DEFINEd in more than one place. */

/* Defined if you have a curses library (ncurses preferred). */
#undef HAVE_LIBCURSES

/* Defined if start is defined.  */
#undef HAVE_START_SYMBOL

/* Defined if _start is defined.  */
#undef HAVE_USCORE_START_SYMBOL

/* Defined if __bss_start is defined.  */
#undef HAVE_USCORE_USCORE_BSS_START_SYMBOL

/* Defined if edata is defined.  */
#undef HAVE_EDATA_SYMBOL

/* Defined if _edata is defined.  */
#undef HAVE_USCORE_EDATA_SYMBOL

/* Defined if end is defined.  */
#undef HAVE_END_SYMBOL

/* Defined if _end is defined.  */
#undef HAVE_USCORE_END_SYMBOL

/* Defined if an absolute indirect call/jump must NOT be prefixed with `*'.  */
#undef ABSOLUTE_WITHOUT_ASTERISK

/* Defined if the user specifies --enable-preset-menu=FILE.  */
#undef PRESET_MENU_STRING

/* Defined if the user specified --enable-auto-linux-mem-opt.  */
#undef AUTO_LINUX_MEM_OPT
